/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleVertexAiFeatureOnlineStoreFeatureviewConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the FeatureOnlineStore to use for the featureview.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#feature_online_store GoogleVertexAiFeatureOnlineStoreFeatureview#feature_online_store}
    */
    readonly featureOnlineStore: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#id GoogleVertexAiFeatureOnlineStoreFeatureview#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A set of key/value label pairs to assign to this FeatureView.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#labels GoogleVertexAiFeatureOnlineStoreFeatureview#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the FeatureView. This value may be up to 60 characters, and valid characters are [a-z0-9_]. The first character cannot be a number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#name GoogleVertexAiFeatureOnlineStoreFeatureview#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#project GoogleVertexAiFeatureOnlineStoreFeatureview#project}
    */
    readonly project?: string;
    /**
    * The region for the resource. It should be the same as the featureonlinestore region.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#region GoogleVertexAiFeatureOnlineStoreFeatureview#region}
    */
    readonly region: string;
    /**
    * big_query_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#big_query_source GoogleVertexAiFeatureOnlineStoreFeatureview#big_query_source}
    */
    readonly bigQuerySource?: GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource;
    /**
    * sync_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#sync_config GoogleVertexAiFeatureOnlineStoreFeatureview#sync_config}
    */
    readonly syncConfig?: GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#timeouts GoogleVertexAiFeatureOnlineStoreFeatureview#timeouts}
    */
    readonly timeouts?: GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts;
}
export interface GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource {
    /**
    * Columns to construct entityId / row keys. Start by supporting 1 only.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#entity_id_columns GoogleVertexAiFeatureOnlineStoreFeatureview#entity_id_columns}
    */
    readonly entityIdColumns: string[];
    /**
    * The BigQuery view URI that will be materialized on each sync trigger based on FeatureView.SyncConfig.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#uri GoogleVertexAiFeatureOnlineStoreFeatureview#uri}
    */
    readonly uri: string;
}
export declare function googleVertexAiFeatureOnlineStoreFeatureviewBigQuerySourceToTerraform(struct?: GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference | GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource): any;
export declare function googleVertexAiFeatureOnlineStoreFeatureviewBigQuerySourceToHclTerraform(struct?: GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference | GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource): any;
export declare class GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource | undefined;
    set internalValue(value: GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource | undefined);
    private _entityIdColumns?;
    get entityIdColumns(): string[];
    set entityIdColumns(value: string[]);
    get entityIdColumnsInput(): string[] | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig {
    /**
    * Cron schedule (https://en.wikipedia.org/wiki/Cron) to launch scheduled runs.
    * To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: "CRON_TZ=${IANA_TIME_ZONE}" or "TZ=${IANA_TIME_ZONE}".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#cron GoogleVertexAiFeatureOnlineStoreFeatureview#cron}
    */
    readonly cron?: string;
}
export declare function googleVertexAiFeatureOnlineStoreFeatureviewSyncConfigToTerraform(struct?: GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference | GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig): any;
export declare function googleVertexAiFeatureOnlineStoreFeatureviewSyncConfigToHclTerraform(struct?: GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference | GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig): any;
export declare class GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig | undefined;
    set internalValue(value: GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig | undefined);
    private _cron?;
    get cron(): string;
    set cron(value: string);
    resetCron(): void;
    get cronInput(): string | undefined;
}
export interface GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#create GoogleVertexAiFeatureOnlineStoreFeatureview#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#delete GoogleVertexAiFeatureOnlineStoreFeatureview#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#update GoogleVertexAiFeatureOnlineStoreFeatureview#update}
    */
    readonly update?: string;
}
export declare function googleVertexAiFeatureOnlineStoreFeatureviewTimeoutsToTerraform(struct?: GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable): any;
export declare function googleVertexAiFeatureOnlineStoreFeatureviewTimeoutsToHclTerraform(struct?: GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable): any;
export declare class GoogleVertexAiFeatureOnlineStoreFeatureviewTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview google_vertex_ai_feature_online_store_featureview}
*/
export declare class GoogleVertexAiFeatureOnlineStoreFeatureview extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_vertex_ai_feature_online_store_featureview";
    /**
    * Generates CDKTF code for importing a GoogleVertexAiFeatureOnlineStoreFeatureview resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleVertexAiFeatureOnlineStoreFeatureview to import
    * @param importFromId The id of the existing GoogleVertexAiFeatureOnlineStoreFeatureview that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleVertexAiFeatureOnlineStoreFeatureview to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.12.0/docs/resources/google_vertex_ai_feature_online_store_featureview google_vertex_ai_feature_online_store_featureview} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleVertexAiFeatureOnlineStoreFeatureviewConfig
    */
    constructor(scope: Construct, id: string, config: GoogleVertexAiFeatureOnlineStoreFeatureviewConfig);
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _featureOnlineStore?;
    get featureOnlineStore(): string;
    set featureOnlineStore(value: string);
    get featureOnlineStoreInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _bigQuerySource;
    get bigQuerySource(): GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference;
    putBigQuerySource(value: GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource): void;
    resetBigQuerySource(): void;
    get bigQuerySourceInput(): GoogleVertexAiFeatureOnlineStoreFeatureviewBigQuerySource | undefined;
    private _syncConfig;
    get syncConfig(): GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference;
    putSyncConfig(value: GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig): void;
    resetSyncConfig(): void;
    get syncConfigInput(): GoogleVertexAiFeatureOnlineStoreFeatureviewSyncConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleVertexAiFeatureOnlineStoreFeatureviewTimeoutsOutputReference;
    putTimeouts(value: GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleVertexAiFeatureOnlineStoreFeatureviewTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
